---
layout: page
title: "System / Service Proposal"
exclude: true
---

<span id="proposal"></span>Assignment 3: System/Service Proposal (35%)
----------------------------------------------------------------------

In this assignment, you will develop a proposal for a new service for a particular client population of a particular information organization.
Some examples might include the development of a public library instruction program for retirees in the community, new ways to track IT support questions related to a litigation support system in a law firm, or a new institutional repository intended to handle the multimedia materials created by performing arts faculty on a university campus.
(These examples are intended to be suggestive, not comprehensive or restrictive.)

The first step will be to identify the particular client population and learn as much about them as possible. This analysis will be evidence-based, i.e., it will rely on prior studies and/or descriptions of the client population and their information behaviors as reported in the literature. 
In class, we will discuss the role of evidence in making practice-based decisions and plans, based on our reading of Koufogiannakis' (2013) keynote address at EBLIP7.

To support your analysis, you will be expected to assemble and assess the relevant literature. 
The methods by which you search for the literature to underpin your analysis will be documented in detail in your final paper. 
In addition, your final paper will include a summary of your findings about the population of interest.

The next step is to plan a service or system that would be useful to the client population. 
The service or system may have been implemented with some other population in the past or in some other organizational setting; you will need to establish that it is novel for your particular population and setting. In particular, the rationale for your proposal should be clearly connected to your (new) knowledge about the client population.

The objective of this assignment is to use empirical evidence about the information behaviors of a client population to plan and justify a new and useful service or system to support the clients' information behaviors.

### Deliverables

1.  <span class="assignmentname">Description of population and setting
    of interest </span>(10%, <span class="due">due Thursday, 24 September</span>): Submit
    a short overview describing the setting you've selected (one
    paragraph), defining/describing the client group based on your
    current knowledge (one paragraph) and your rationale for selecting
    this setting and client group (one paragraph).
2.  Intermediate deliverables (30%):
    -   <span class="assignmentname">Preliminary literature search
        plan</span> (10%, <span class="due">due Thursday, 1 October</span>): Submit a
        plan for identifying the literature to include in your review
        including list of databases/sources to be searched, the search
        strategies to be used, and the inclusion/exclusion criteria to
        be used to evaluate the literature retrieved
    -   <span class="assignmentname">Preliminary client
        description</span> (10%, <span class="due">due Tuesday, 27 October</span>):
        Submit a detailed outline, a concept map/matrix, or a similar
        sketch of what you've learned about the population including the
        preliminary list of references to the articles you're using
        as evidence.
    -   <span class="assignmentname">Preliminary proposal
        description</span> (10%, <span class="due">due Tuesday, 3 November</span>):
        one-paragraph description of the system or service you
        will propose.

3.  <span class="assignmentname">Final proposal</span> (60%, <span
    class="due">due Tuesday, 17 November</span>):
    -   Proposal memo: a 2-page (single-spaced) memo to the leader of
        your information organization, presenting your proposal and
        providing arguments supporting its adoption.
    -   Client description: A brief description (4-6
        pages, single-spaced) of the client population and its
        information behaviors, plus the citations to the evidence used.
    -   Literature search strategy (as appendix to Proposal): a listing
        of the databases/resources you used to learning about the client
        population, and the specific search strategies/terms used
        in each.

Each step in this process of developing the proposal package is described in more detail below.

### Identify the population and setting of interest

As an information professional, you will regularly be expected to develop a new service or system to support a particular set of clients to perform a particular information-related task. 
You'll get some practice with that professional responsibility while completing this assignment.

For the purposes of the assignment, choose a setting and client group of particular interest to you. 
The setting might be a library in a particular institutional setting (e.g., a public library in a mid-sized town in NC or a library in an elementary school serving kindergarten through third grade), a system development team (e.g., the unit responsible for a pharmaceutical company's knowledge management activities or the unit responsible for a financial services company's human resources system), or some other setting in which information professionals are employed.

You will also choose a particular client group relevant to that setting.
In the examples of organizations just provided, corresponding client groups might be the teenagers that could potentially use the public library, second-grade teachers, members of the pharmaceutical company's marketing division, and hiring managers/supervisors distributed throughout the financial services company. 
So that this assignment will be most useful to you, I would encourage you to select a setting and client group that you anticipate/hope will be part of your professional future.

<span class="assignmentname">Intermediate deliverable</span>: You will write one paragraph describing the setting you've selected, and one paragraph defining/describing the client group (based on your current knowledge). 
In addition, write one paragraph about ***why*** you selected this setting and client group.

### Assemble and assess the evidence related to the population and setting of interest

You will begin by planning the ways in which you will assemble the relevant evidence. 
You should decide which databases/sources you will search and what search strategy(ies) you will use in each. 
You should specify inclusion and exclusion criteria for which studies will be included in your summary. 
You should aim for a comprehensive set of evidence to support your proposal. 
Start with those articles that are most core to your interests (i.e., directly addressing some aspect of your selected population within a similar setting) and work your way out from there. 
You may need to adjust the scope of your population as you learn more about them; please discuss such adjustments with me as you go along.

[Bates (1989, p.412)](/schedule/#Bates1989) suggests avariety of ways to identify relevant literature; these can serve as a guide for your own literature searching. 
They of course include subject searches in relevant databases, but they also include footnote chasing and citation searching, author searching, and browsing journal tables of contents and bookshelves that might be particularly fruitful. 
You are expected to incorporate all or most of these methods in your own
searching.

The process of searching the literature will help you to identify possibilities for a new service or system that can be the focus of your proposal. 
For example, you may have focused on elderly users of public libraries. 
Studies of their current information use may conclude that they are interested in accessing more information about current politics, but are hampered from reading current materials by decreasing visual abilities. In such a situation, you may propose a program for loaning e-readers to the library's clients, with easy interactions for increasing the font size.

After you've assembled some evidence (i.e., articles or publications), you will need to assess them for their quality, relevance and usefulness for your purposes. 
Your quality criteria might include such characteristics as the validity of the research design, the quality and
size of the sample included in the study, the validity of the analysis conducted, and the credibility of the conclusions as they relate to the underlying data. 
Your relevance/usefulness criteria might include such characteristics as the match between your population of interest and the study sample, and the similarity of the study context and your own setting of interest. Additional criteria may also apply, as you make decisions about which evidence to weigh most heavily in developing your proposal.

There will be a lot of variability in the number of articles and other materials you might use for this assignment, but here is a bit of guidance on scope/scale: 
-   I would expect that you might identify hundreds of potentially useful documents through your literature search; 
-   I would expect that you would closely examine the abstracts of over 100 documents; 
-   I would expect that you would examine the full text of 30-60 articles; 
-   I would expect that you would identify and read 20-30 articles to be cited in your summary of the characteristics of your selected population.

<span class="assignmentname">Intermediate deliverable</span>: You will develop a preliminary plan for identifying the literature to include in your review. 
The plan should include the list of databases/sources to be searched, the search strategies to be used, and the inclusion/exclusion criteria to be used to evaluate the literature retrieved.

<span class="assignmentname">Final deliverable</span>: In an appendix to your final proposal, you will list each database searched and provide the details of the search terms/strategies used and the number of items retrieved with each strategy *for each database/source*. 
You should also describe your inclusion/exclusion criteria (e.g., range of years or other limits you placed on your searches) and the criteria you used to make judgments about the relevance or usefulness of the items you selected. 
This appendix should be a bulleted list or outline format, rather than narrative. There's no limit on its length, but it is likely to be 1-3 pages, single-spaced.

### Extracting and synthesizing knowledge

As you identify and assess the relevant evidence about your population of interest, you will be developing your own knowledge about that population and their information interactions within the context of your chosen setting. 
As an appendix to your proposal, you will summarize what you learned. 
What do we know about their general characteristics? 
What do we know about their information needs, their information seeking, their use of information, and the context in which all these information behaviors occur? 
Begin your summary with a revised version of the original description/definition of the population and setting that you created at the beginning of this assignment, to provide a bit of context. 
Then provide a summary of what you know about that population.
Be sure to provide details about the population that will support your proposal.

Intermediate deliverable: Provide a detailed outline, a concept map/matrix, or a similar sketch of what you've learned about the population. 
Include the preliminary list of references to the articles you're using as evidence.

Final deliverable: In an appendix to your final proposal, summarize our current knowledge about your population of interest, particularly in connection with your selected setting and the focus of your proposal.
This appendix should be 4-6 pages, single-spaced. 
The list of references should be included on separate pages.

### Proposing the development of a new system or service

The purpose of the investigations you've done for this assignment is to understand the population of interest well enough to design and develop a new system or service that will be useful to them in addressing some of their information needs. 
Based on what you've learned about your selected population, you will propose such a system or service. It does not have to be the first of its type in the world, but it should be plausible that it has not yet been implemented within your chosen setting.

As Koufogiannakis (2013) points out, information work occurs within organizational settings, so an initial proposal is not the same as agreement to implement that proposal. 
Thus, your proposal will need to "sell" your idea to your colleagues (or at least your supervisor, to carry forward). 
You must describe the system or service you're proposing, but you also must persuasively argue that it will serve an important purpose in the lives of the population of interest and that it will be feasible for your institution to implement it. 
The first of those sets of arguments will be based on logical connections back to the summary of the characteristics of the population; don't repeat all the details in your proposal, but do clearly connect the proposal to the findings in your summary of the population's characteristics. 
The second set of arguments will be based on the practical considerations within your imagined setting; be realistic but not pessimistic.

The proposal will be written in the form of a memo, from you to the leader of your information organization. It should be no longer than 2 single-spaced pages.

<span class="assignmentname">Intermediate deliverable</span>: Provide a one-paragraph description of the system or service you will propose.

<span class="assignmentname">Final proposal package</span>: The final proposal package will consist of:

-   the memo proposing the system or service 
-   a summary of our current knowledge about the user population (4-6
    pages, single-spaced), plus the list of references used as evidence;
    and
-   the listing of your methods for conducting the literature review,
    including which databases were searched, the search strategies used,
    number of items retrieved with each, and your
    selection/relevance criteria.

### Evaluation criteria

The final memo will be evaluated based on the thoroughness and rigor of the literature review methods, the quality of the synthesis of the literature included in the summary of your population's characteristics, the logic connecting those findings to your proposal, the usefulness, originality and feasibility of your proposal, and the clarity of expression of the final product.