---
layout: page
---

Course Description
------------------

INLS 500 is a course that surveys human information interactions through broad examination of information science literature. 
Students examine cognitive, social, organizational/institutional, and behavioral approaches to understanding interactions between people and information.
Emphasis is placed on the role of the information professional or information scientist as mediator, and students are encouraged to apply analyze current events and situations.

This course undergirds much of the SILS curriculum because it introduces students to core concepts that have implications for the practice of information science and librarianship. 
It is expected that it will be taken during the first or second semester of the student's career at SILS.

Objectives
----------

Students completing this course will:

-   become familiar with the empirical and theoretical literature 
    related to information seeking, including the recognition of
    information needs, actions taken to resolve those needs, the roles
    of intermediaries (both human and machine), and the retrieval and
    use of information;
-   understand key concepts related to the ways in which information is
    created, structured, disseminated and used, with particular emphasis
    on scholarly information behaviors;
-   be able to investigate the ways in which the context of an
    information interaction can affect the process and outcomes of that
    interaction;
-   be able to investigate information behaviors and practices,
    including the impact of technology on human information
    interactions; and
-   critically apply theories and empirical findings to the definition
    and solution of problems related to human information interactions.

Readings
--------

As this is a "survey" course, students will be expected to complete readings in preparation for each class meeting. 
The assigned readings are listed on the [course schedule]({{ base.url }}/schedule/ "course schedule") and will be made available electronically through the [UNC libraries](http://library.unc.edu "library website"), the [Sakai site for the course](https://sakai.unc.edu/portal/site/inls500-001-fa2015 "Sakai INLS 500-001 Fall 2015"). 
No textbook is required.

Assignments and Evaluation
--------------------------

Three individual assignments, one group project/paper and participation will be used to determine the grade for the course. The [assignment page]({{ base.url }}/assignments/ "Assignments page") for the course provides the details, due dates (preliminary and final deliverables) and evaluation criteria for each assignment. 

All assignments will be submitted electronically unless otherwise approved with the instructor *in advance.*

1.  Observation and analysis of an information-seeking event (20%): Each
    student will observe a personal information-seeking event
    and analyze the event in terms of the concepts and ideas discussed
    in the course.
2.  Evidence summary (15%): Each student will write an evidence summary
    of one study (using the EBLIP evidence summaries as a model which
    include implications for practice), will present it briefly in
    class, and will moderate an online discussion of it.
3.  System/service proposal (35%): Each student will select a particular
    population of interest and, based on a review of what we already
    know about that population, will develop a proposal for a new system
    or service for that population.
4.  Analysis of Scholarly Communication (20%): Each team of students
    will select a set of related articles and will analyze the structure
    and content of each paper, as well as the way it has been used by
    other scholars (i.e., through an analysis of their citations to it).
    All members of the team will receive the same grade for the project.
5.  Class participation (10%): Be prepared for each class by completing
    the assigned reading(s); ask questions and participate in the class
    discussions and activities both in class and online; respond to and
    discuss classmates' evidence summaries online.

Grading
-------

UNC-CH graduate students are graded on the H/P/L/F scale. The following definitions of these grades will be used for this course. While assignments are not graded "on a curve," most grades for graduate students are expected to be Ps.

Additional information about grading at UNC can be found in the [Undergraduate Bulletin](http://www.unc.edu/ugradbulletin/procedures1.html#grading "grading section of the Undergraduate Bulletin") and the [Graduate School Handbook](http://handbook.unc.edu/grading.html "grading section of the Graduate School Handbook").

#### Grading scale for INLS 500 (graduate students)

<table class="grades">
  <!--<caption>Grading scale for INLS 500 (graduate students)</caption>-->
  <tr>
    <th>Letter grade&nbsp;</th>
    <th>Numeric range&nbsp;</th>
    <th class="description">Description of grade</th>
  </tr>  
  <tr>
    <td>H</td>
    <td>95-100</td>
    <td>High Pass: Clear excellence; beyond expectations for the course. </td>
  </tr>
  <tr>
    <td>P</td>
    <td>80-94</td>
    <td>Pass: Entirely satisfactory; fully meets expectations for the course.</td>
  </tr>
  <tr>
    <td>L</td>
    <td>70-79</td>
    <td>Low Pass: Minimally acceptable; clear weaknesses in performance.</td>
  </tr>
  <tr>
    <td>F</td>
    <td>Below 70</td>
    <td>Fail: Unacceptable performance.</td>
  </tr>
  <tr>
    <td>IN</td>
    <td>NA</td>
    <td>Work incomplete.</td>
  </tr>
</table>
<br/>

#### Grading scale for INLS 500 (undergraduate students) 

<table class="undergrad">
  <!--<caption>Grading scale for INLS 500 (undergraduate students)</caption>-->
  <tr>
    <th scope="col">Letter grade&nbsp;</th>
    <th scope="col">Numeric range&nbsp;</th>
    <th scope="col" class="description">Description of grade</th>
  </tr>
  <tr>
    <td>A</td>
    <td>95-100</td>
    <td>Mastery of course content at the highest level of attainment that can reasonably be expected of students at a     given stage of development.</td>
  </tr>
  <tr>
    <td>A-</td>
    <td>90-94</td>
    <td>&nbsp;</td>
  </tr>
  <tr>
    <td>B+</td>
    <td>88-89</td>
    <td>&nbsp;</td>
  </tr>
  <tr>
    <td>B</td>
    <td>86-87</td>
    <td>Strong performance demonstrating a high level of attainment for a student at a given stage of development.</td>
  </tr>
  <tr>
    <td>B-</td>
    <td>84-85</td>
    <td>&nbsp;</td>
  </tr>
  <tr>
    <td>C+</td>
    <td>82-83</td>
    <td>&nbsp;</td>
  </tr>
  <tr>
    <td>C</td>
    <td>80-81</td>
    <td>A totally acceptable performance demonstrating an adequate level of attainment for a student at a given stage of development. </td>
  </tr>
  <tr>
    <td>C-</td>
    <td>78-79</td>
    <td>&nbsp;</td>
  </tr>
  <tr>
    <td>D+</td>
    <td>74-77</td>
    <td>&nbsp;</td>
  </tr>
  <tr>
    <td>D</td>
    <td>70-73</td>
    <td>A marginal performance in the required exercises demonstrating a minimal passing level of attainment for a student at a given stage of development. </td>
  </tr>
  <tr>
    <td>F</td>
    <td>Below 70</td>
    <td>For whatever reasons, an unacceptable performance. The F grade indicates that the student's performance in the required exercises has revealed almost no understanding of the course content. </td>
  </tr>
  <tr>
    <td>IN</td>
    <td>NA</td>
    <td>Work incomplete.</td>
  </tr>
</table>
<br/>

Honor Code
----------

The Honor Code, which prohibits giving or receiving unauthorized aid in the completion of assignments, is in effect in this class.

Assignments for this course are to be completed individually - except the group project. It is your responsibility if you have any doubt to confirm whether or not collaboration is permitted.

Be careful about plagiarism. Whenever you use the words or ideas of others, either as direct quotes or paraphrased text, they should be properly attributed through quotations and/or citations. APA citationformat is required for assignments in this class. 
A [handout on plagiarism](http://writingcenter.unc.edu/handouts/plagiarism/ "UNC Writing center handout on plagiarism") developed by the [Writing Center](http://writingcenter.unc.edu "UNC Writing Center") provides an overview of plagiarism and offers suggestions for avoiding it.

You can learn more about the UNC Honor Code at [http://honor.unc.edu](http://honor.unc.edu) and about the Instrument of Student Governance at [http://instrument.unc.edu](http://instrument.unc.edu).

Please contact the instructor if you have any questions about the Honor Code or its application to your work in this class.

Additional Course Policies
--------------------------

Changes to the schedule will be announced in class and in Sakai.

Email is the most efficient way to communicate with the instructor outside of class for brief questions or notes. 
Normally, you should expect a response within 24 hours. 
I am available during office hours and, by appointment, at other times.

Assignments are due at any time on the specified due date, unless a time is otherwise specified. 
With the instructor's permission *in advance*, late assignments will be accepted with a penalty.

We will be using many electronic resources in class, so it is a good idea to have your laptop with you even if you don't intend to use it to take notes. 
Please use your laptops or other electronic devices only to support your class participation.
Please do not engage in email or social media.

You will be using SILS library and IT services during the course of the
semester. Please remember that many of your fellow students also need to
use the same equipment and materials. Follow the proper checkout
procedures and return materials promptly to be a good SILS citizen.

In case of adverse weather conditions, the course may be held online
(via video or online discussion) or cancelled as appropriate. Official
communications will be sent via e-mail.